RequestError

Enum RequestError 

pub enum RequestError {
    UnsupportedCommand {
        command: String,
        msg: RequestMsgData,
        peer: Peer,
    },
    MissingTarget {
        msg: RequestMsgData,
        peer: Peer,
    },
    InvalidType {
        ty: i32,
        msg: RequestMsgData,
        peer: Peer,
    },
    MissingCommand {
        peer: Peer,
    },
    InvalidValue {
        msg: RequestMsgData,
        peer: Peer,
    },
}

Variants



UnsupportedCommand

Received a query with a custom command that is not registered

Fields

command: String

The unknown command

msg: RequestMsgData

The message we received from the peer.

peer: Peer

The peer the message originated from.



MissingTarget

The target field of message was required but was empty

Fields

peer: Peer


InvalidType

Received a message with an unknown type

Fields

ty: i32
peer: Peer


MissingCommand

Received a request with no command attached.

Fields

peer: Peer


InvalidValue

Ignored Request due to message’s value being this peer’s id.

Fields

peer: Peer