RpcEvent

Enum RpcEvent 

pub enum RpcEvent {
    CustomRequest(CustomCommandRequest),
    ResponseResult(ResponseResult),
    RoutingUpdated {
        peer: Peer,
        old_peer: Option<Peer>,
    },
    Bootstrapped(Arc<Bootstrapped>),
    ReadyToCommit {
        query: Arc<RwLock<Query>>,
        tx_commit_messages: Sender<CommitMessage>,
    },
    QueryResult(Arc<QueryResult>),
    QueryResponse(Arc<InResponse>),
}

Variants



CustomRequest(CustomCommandRequest)

Result wrapping an incomming Request Only emits Ok on custom/external commands. Errs on any request error (custom or non-custom)



ResponseResult(ResponseResult)

Result wrapping an incomming Response Emits for any valid response



RoutingUpdated

The routing table has been updated.

Fields

peer: Peer

The ID of the peer that was added or updated.

old_peer: Option<Peer>

The ID of the peer that was evicted from the routing table to make room for the new peer, if any.



Bootstrapped(Arc<Bootstrapped>)

Emitted when bootstrapping is complete



ReadyToCommit

Only emitted when Query is made with Commit::Custom

Fields

query: Arc<RwLock<Query>>

The query we are commiting for

tx_commit_messages: Sender<CommitMessage>


QueryResult(Arc<QueryResult>)

A completed query.

No more responses are expected for this query



QueryResponse(Arc<InResponse>)

A single response for a request made for a query