pub struct CustomCommandRequest {
pub request: Box<RequestMsgData>,
pub peer: Peer,
pub command: ExternalCommand,
}Expand description
Custom incoming request to a registered command
Note
Custom commands are not automatically replied to and need to be answered manually The query we received and need to respond to
Fields
request: Box<RequestMsgData>peer: PeerPeer that sent th erequest
command: ExternalCommandTrait Implementations